==> flutterskel-0.0.11.tar.gz: lib/widgets/stateless/RawStatelessWidgetClass.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/resources/colors/ColorResources.dart' as arch;
import 'package:flutterskel/resources/dimensions/DimensionResources.dart' as arch;
import 'package:flutterskel/resources/fonts/FontResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart' as arch;
import 'package:flutterskel/resources/themes/ThemeResources.dart' as arch;
import 'package:flutterskel/routing/page/PageRouter.dart' as arch;
import 'package:flutterskel/routing/url/UrlRouter.dart' as arch;
import 'package:flutterskel/userinformation/UserInformationRepository.dart' as arch;
import 'package:flutterskel/configuration/Configuration.dart' as arch;
import 'package:provider/provider.dart';

/// Raw abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatelessWidget<
                  // Data
                  DataSource,
                  // Routing
                  UrlRouter extends arch.UrlRouter,
                  PageRouter extends arch.PageRouter,
                  // Configuration
                  Configuration extends arch.Configuration,
                  // User Information
                  UserInformationRepository extends arch.UserInformationRepository,
                  // Themes (Fonts/Dimensions/Colors)
                  ThemeRepository extends arch.ThemeRepository,
                  Theme extends arch.ThemeResources,
                  Colors extends arch.ColorResources,
                  Dimensions extends arch.DimensionResources,
                  Fonts extends arch.FontResources,
                  // Strings
                  Strings extends arch.StringResources,
                  // Images and Icons
                  Images,
                  Icons> extends StatelessWidget {

  // Data
  DataSource getDataSource(BuildContext context) => Provider.of<DataSource>(context);

  // Routing
  UrlRouter urlRouter(BuildContext context) => Provider.of<UrlRouter>(context);
  PageRouter pageRouter(BuildContext context) => Provider.of<PageRouter>(context);

  // Configuration
  Configuration configuration(BuildContext context) => Provider.of<Configuration>(context);

  // User Information
  UserInformationRepository userInformation(BuildContext context) => Provider.of<UserInformationRepository>(context);

  // Strings
  StringsRepository<Strings> stringsRepository(BuildContext context) => Provider.of<StringsRepository<Strings>>(context);
  Strings strings(BuildContext context) => stringsRepository(context).strings;

  // Theme
  ThemeRepository themeRepo(BuildContext context) => Provider.of<ThemeRepository>(context);
  Theme theme(BuildContext context) => themeRepo(context).theme;
  Colors colors(BuildContext context) => theme(context).colors;
  Dimensions dimensions(BuildContext context) => theme(context).dimensions;
  Fonts fonts(BuildContext context) => theme(context).fonts;

  // Images and Icons
  Images images(BuildContext context) => Provider.of<Images>(context);
  Icons icons(BuildContext context) => Provider.of<Icons>(context);

}

==> flutterskel-0.0.14.tar.gz: lib/widgets/stateless/RawStatelessWidgetClass.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/resources/colors/ColorResources.dart' as arch;
import 'package:flutterskel/resources/dimensions/DimensionResources.dart' as arch;
import 'package:flutterskel/resources/fonts/FontResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart' as arch;
import 'package:flutterskel/resources/themes/ThemeResources.dart' as arch;
import 'package:flutterskel/routing/page/PageRouter.dart' as arch;
import 'package:flutterskel/routing/url/UrlRouter.dart' as arch;
import 'package:flutterskel/userinformation/UserInformationRepository.dart' as arch;
import 'package:flutterskel/configuration/Configuration.dart' as arch;
import 'package:provider/provider.dart';

/// Raw abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatelessWidget<
                  // Data
                  DataSource,
                  // Routing
                  UrlRouter extends arch.UrlRouter,
                  PageRouter extends arch.PageRouter,
                  // Configuration
                  Configuration extends arch.Configuration,
                  // User Information
                  UserInformationRepository extends arch.UserInformationRepository,
                  // Themes (Fonts/Dimensions/Colors)
                  ThemeRepository extends arch.ThemeRepository,
                  Theme extends arch.ThemeResources,
                  Colors extends arch.ColorResources,
                  Dimensions extends arch.DimensionResources,
                  Fonts extends arch.FontResources,
                  // Strings
                  Strings extends arch.StringResources,
                  // Images and Icons
                  Images,
                  Icons> extends StatelessWidget {

  // Data
  DataSource getDataSource(BuildContext context) => Provider.of<DataSource>(context);

  // Routing
  UrlRouter urlRouter(BuildContext context) => Provider.of<UrlRouter>(context);
  PageRouter pageRouter(BuildContext context) => Provider.of<PageRouter>(context);

  // Configuration
  Configuration configuration(BuildContext context) => Provider.of<Configuration>(context);

  // User Information
  UserInformationRepository userInformation(BuildContext context) => Provider.of<UserInformationRepository>(context);

  // Strings
  StringsRepository stringsRepository(BuildContext context) => Provider.of<StringsRepository>(context);
  Strings strings(BuildContext context) => stringsRepository(context).strings;

  // Theme
  ThemeRepository themeRepo(BuildContext context) => Provider.of<ThemeRepository>(context);
  Theme theme(BuildContext context) => themeRepo(context).theme;
  Colors colors(BuildContext context) => theme(context).colors;
  Dimensions dimensions(BuildContext context) => theme(context).dimensions;
  Fonts fonts(BuildContext context) => theme(context).fonts;

  // Images and Icons
  Images images(BuildContext context) => Provider.of<Images>(context);
  Icons icons(BuildContext context) => Provider.of<Icons>(context);

}
